@@ -341,7 +341,10 @@ class LabelmeDict:
 
     @classmethod
     def gen_ocr_data(cls, imfile=None, **kwargs):
-        """" 支持调用PaddleOCR进行预识别 """
+        """" 支持调用PaddleOCR进行预识别
+
+        该接口是为了方便性保留，更推荐使用 PaddleOCR.auto_labelme的功能进行批量识别
+        """
         from paddleocr import PaddleOCR
         ppocr = PaddleOCR.get_paddleocr()
 
